;;; app-org.el --- Org mode configuration
;;; Commentary

;; Configuration and extra packages for org-mode.

;;; Code:

(use-package org
  :bind
  ("C-c l" . org-store-link)
  ("C-c a" . org-agenda)
  :config
  (require 'ox-rss)
  ;; Org directories
  (setq org-directory "~/Dropbox/Org"
        org-default-notes-file (concat org-directory "/todo.org"))
  (setq org-agenda-files '("~/Dropbox/Org/"))
  ;; Default show all of the things
  (setq org-startup-folded nil)
  ;; Exports don't have TOC or numbering by default
  (setq org-export-with-toc nil)
  (setq org-export-with-creator nil)
  (setq org-export-with-section-numbers nil)
  (setq org-export-with-sub-superscripts nil)
  ;; Indent by default
  (setq org-startup-indented t)
  ;; Split right if window is wide enough
  (defadvice org-agenda (around split-vertically activate)
    (let ((split-width-threshold 80))  ; or whatever width makes sense for you
      ad-do-it))
  ;;warn me of any deadlines in next 7 days
  (setq org-deadline-warning-days 7)
  ;;show me tasks scheduled or due in next fortnight
  (setq org-agenda-span (quote fortnight))
  ;; Agenda Settings
  (setq org-agenda-custom-commands
        '(("c" "Simple agenda view"
           ((tags "PRIORITY=\"A\""
                  ((org-agenda-skip-function '(org-agenda-skip-entry-if 'todo 'done))
                   (org-agenda-overriding-header "High-priority unfinished tasks:")))
            (agenda "")
            (alltodo ""
                     ((org-agenda-skip-function
                       '(or (dctrud/org-skip-subtree-if-priority ?A)
                            (org-agenda-skip-if nil '(scheduled deadline)))))))))))

(use-package org-bullets
  :config
  (setq org-hide-leading-stars t)
  (add-hook 'org-mode-hook
            (lambda ()
              (org-bullets-mode t))))

(use-package org-journal
  :ensure t
  :config
  (setq org-journal-dir "~/Org/Journal/")
  (setq org-journal-file-type 'weekly))

(use-package ox-twbs
  :ensure t)

(use-package org-web-tools
  :ensure t)

(use-package org-download
  :ensure t)

(provide 'app-org)

;;; app-org.el ends here
